queryContactPhoto method

Future<Uint8List> queryContactPhoto(
  1. Uri? uri, {
  2. bool? fullSize = false,
})

Get the bytes of the photo specified by uri. To get the full size of contact's photo the optional parameter fullSize must be set to true. By default the returned photo is the thumbnail representation of the contact's photo.

Implementation

Future<Uint8List> queryContactPhoto(Uri? uri, {bool? fullSize = false}) async {
  return await _channel.invokeMethod("getContactPhoto", {"photoUri": uri?.path, "fullSize": fullSize});
}